@@ -6,6 +6,7 @@ import re
 
 import six
 
+from rook import utils
 from rook.config import ImportServiceConfig
 from rook.serverless import on_lambda
 from rook.fork_utils import detect_multiprocessing
@@ -17,7 +18,7 @@ _throw_errors = False
 _fork = None
 _original_args = None
 
-_TRUE_VALUES = ['y', 'Y', 'yes',  'Yes',  'YES', 'true', 'True', 'TRUE', '1', True]
+_TRUE_VALUES = ['y', 'Y', 'yes',  'Yes',  'YES', 'true', 'True', 'TRUE', '1', True, b'True']
 
 
 def start(token=None,
@@ -37,6 +38,7 @@ def start(token=None,
           fork=None,
           enable_monitor=None,
           sources=None,
+          quiet=None,
           **kwargs):
     global _rook, _debug, _throw_errors, _original_args, _fork
 
@@ -65,6 +67,9 @@ def start(token=None,
     else:
         _debug = os.environ.get('ROOKOUT_DEBUG') in _TRUE_VALUES
 
+    if not isinstance(quiet, bool):
+        quiet = os.environ.get('ROOKOUT_QUIET') in _TRUE_VALUES
+
     if not isinstance(log_to_stderr, bool):
         log_to_stderr = os.environ.get('ROOKOUT_LOG_TO_STDERR') in _TRUE_VALUES
 
@@ -109,7 +114,10 @@ def start(token=None,
 
     _enable_monitor = enable_monitor or os.environ.get('ROOKOUT_ENABLE_MONITOR', True) in _TRUE_VALUES
 
+
     try:
+        detect_uwsgi()
+
         token = token.strip().strip("'\"")
         proxy = proxy.strip().strip("'\"")
         host_specified = host_specified.strip().strip("'\"")
@@ -162,6 +170,9 @@ def start(token=None,
             if log_to_stderr is not None:
                 LoggingConfiguration.LOG_TO_STDERR = log_to_stderr
 
+            if quiet is not None:
+                LoggingConfiguration.QUIET = quiet
+
             if proxy is not None and not isinstance(proxy, six.string_types):
                 raise RookInvalidOptions('proxy should be a String')
 
@@ -192,7 +203,8 @@ def start(token=None,
                                           proxy=proxy, throw_errors=throw_errors, log_level=log_level,
                                           log_to_stderr=log_to_stderr, log_file=log_file, git_commit=git_commit,
                                           git_origin=git_origin, tags=tags, labels=labels, async_start=async_start,
-                                          use_import_hook=use_import_hook, fork=_fork, enable_monitor=_enable_monitor, sources=sources)
+                                          use_import_hook=use_import_hook, fork=_fork, enable_monitor=_enable_monitor,
+                                          sources=sources, quiet=quiet)
 
             if (host == "staging.cloud.agent.rookout.com") or (host == "cloud.agent.rookout.com"):
                 raise RookOldServers()
@@ -230,6 +242,31 @@ def start(token=None,
             traceback.print_exc()
 
 
+
+def detect_uwsgi():
+    try:
+        import uwsgi
+        from rook.logger import logger
+        found_postfork = False
+        if 'enable-threads' not in uwsgi.opt or uwsgi.opt['enable-threads'] not in _TRUE_VALUES:
+            logger.warning("enable-threads should be set to true.\n"
+                         "See: https://docs.rookout.com/docs/python-setup/#uwsgi-applications")
+
+        import uwsgidecorators
+        for hook in uwsgidecorators.postfork_chain:
+            if "rook" in hook.f.__name__:
+                found_postfork = True
+        if not found_postfork:
+            logger.debug("Couldn't find rookout in uwsgi postfork hooks.\n"
+                         "See https://docs.rookout.com/docs/python-setup/#uwsgi-applications")
+        else:
+            logger.debug("found postfork")
+    except ImportError:
+        pass # Not running in uwsgi
+    except Exception as e: # Not running in master mode
+        if str(e) != "you have to enable the uWSGI master process to use this module":
+            raise
+
 def capture_exception(exc):
     from rook.collect import exception_collect
 
@@ -298,6 +335,6 @@ def _print_user_configuration(**kwargs):
         for key, value in kwargs.items():
             if value:
                 config_string = config_string + ("%s: %s, " % (key, value))
-        six.print_("RookOptions: " + config_string)
+        utils.quiet_print("RookOptions: " + config_string)
     except Exception:
         six.print_("Error in printing user configuration")
