@@ -11,16 +11,14 @@ def add_info(obj):
         logger.warning("Failed to get hostname", exc_info=1)
         obj.hostname = ""
 
-    s = socket.socket(socket.AF_INET, socket.SOCK_DGRAM)
-    try:
-        # doesn't even have to be reachable
-        s.connect(('10.255.255.255', 1))
-        obj.ip = s.getsockname()[0]
-    except Exception:
-        logger.warning("Failed to get ip", exc_info=1)
-        obj.ip = ""
-    finally:
-        s.close()
+    with socket.socket(socket.AF_INET, socket.SOCK_DGRAM) as s:
+        try:
+            # doesn't even have to be reachable
+            s.connect(('10.255.255.255', 1))
+            obj.ip = s.getsockname()[0]
+        except Exception:
+            logger.warning("Failed to get ip", exc_info=1)
+            obj.ip = ""
 
     obj.machine_type = platform.machine()
     obj.network = platform.node()
