@@ -124,7 +124,7 @@ class PythonObjectNamespace(Namespace):
             if hasattr(self.obj, '__dict__') and self.obj.__dict__ and name in self.obj.__dict__:
                 return PythonObjectNamespace(self.obj.__dict__[name])
             if hasattr(self.obj, '__slots__') and self.obj.__slots__ and name in self.obj.__slots__:
-                return PythonObjectNamespace(self.obj.__slots__[name])
+                return PythonObjectNamespace(getattr(self.obj, name))
 
             raise RookAttributeNotFound(name)
         except AttributeError:
